#
# Copyright (c) 2015 Sam4Mobile
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# Install service file, reload systemd daemon if necessary
execute "systemd-reload" do
  command "systemctl daemon-reload"
  action :nothing
end

# Java is needed by Storm. We may install it with package
java_package = node['storm-platform']['java'][node['platform']]
package java_package if !java_package.to_s.empty?

if node['storm-platform']['auto_restart']
  config_files = [
    "#{node['storm-platform']['prefix_home']}/storm/conf/storm.yaml",
    "#{node['storm-platform']['prefix_home']}/storm/log4j2/cluster.xml",
    "#{node['storm-platform']['prefix_home']}/storm/log4j2/worker.xml"
  ].map do |path|
    "template[#{path}]"
  end
else config_files = []
end

storm_cluster = cluster_search(node['storm-platform'])
app_list = storm_cluster['my_id'] == node['storm-platform']['nimbus_id'] ?
  ["nimbus", "logviewer", "ui"] : ["supervisor", "logviewer"]

app_list.each {|app|
  template "/usr/lib/systemd/system/storm-#{app}.service" do
    variables     :app => app
    mode          "0644"
    source        "storm.service.erb"
    notifies      :run, 'execute[systemd-reload]', :immediately
  end

  # Because Storm takes some time to start, we wait a bit so further tests pass
  execute "sleep" do
    command "sleep 20"
    action :nothing
  end

  service "storm-#{app}" do
    provider Chef::Provider::Service::Systemd
    supports :status => true, :restart => true
    action [ :enable, :start ]
    subscribes :restart, config_files
    notifies :run, 'execute[sleep]', :delayed
  end
}
